@@ -29,13 +29,14 @@ sub add_feed {
         $feed,
 #        HTML::Tidy->new,
         undef,
-        HTML::Scrubber->new(
-            rules => [
-                style => 0,
-                script => 0,
-            ],
-            default => [ 1, { '*' => 1, style => 0 } ],
-        ),
+#        HTML::Scrubber->new(
+#            rules => [
+#                style => 0,
+#                script => 0,
+#            ],
+#            default => [ 1, { '*' => 1, style => 0 } ],
+#        ),
+        undef,
     );
 
     $self->_write_index(
@@ -60,7 +61,7 @@ sub templatize {
     $tt->process("$skin/template/index.tt", {
         %{ $self->conf->{template} },
         feed  => $feed,
-        members => $self->_get_members($context, $feed),
+        members => [ $context->subscription->feeds ],
     }, \my $out) or $context->error($tt->error);
     $out;
 }
@@ -70,7 +71,7 @@ sub _sanitize_entries {
     
     foreach my $entry ($feed->entries) {
 #        $entry->{body} = $tidy->clean($entry->{body});
-        $entry->{body} = $scrubber->scrub($entry->{body});
+        $entry->{body} = $scrubber->scrub($entry->{body}) if $scrubber;
     }
 }
 
@@ -93,21 +94,5 @@ sub _apply_skin {
     ) or $context->error("rcopy: $!");
 }
 
-sub _get_members {
-    my ($self, $context, $feed) = @_;
-    
-    my %members;
-    foreach my $entry ($feed->entries) {
-        unless ($members{$entry->source->id}) {
-            $members{$entry->source->id} = {
-                title => $entry->source->title,
-                link  => $entry->source->link,
-            };
-        }
-    }
-    
-    return [ sort { $a->{title} cmp $b->{title} } values %members ];
-}
-
 1;
 
